@@ -5,7 +5,7 @@ import json
 
 def redistribute_sensors(
     input_folder, output_folder, grid_count, min_sensor_count=2000,
-    extension='pts', verbose=False
+    extension='pts', grid_info=None, verbose=False
 ):
     """Create new sensor grids folder with evenly distributed sensors.
 
@@ -52,25 +52,30 @@ def redistribute_sensors(
             over grid_count. Default: 2000.
         extension: Extension of the files to collect data from. Default is ``pts`` for
             sensor files. Another common extension is ``csv`` for generic data sets.
+        grid_info: Optional list of dictionaries with grid information. Use this instead
+            of the expected _info.json file in the input_folder.
         verbose: Set to True to get verbose reporting. Default: False.
 
     Returns:
-        A tuple with two elements
+        A tuple with three elements
 
         - grid_count: Number of output sensor grids. Keep in mind that this number can
           be adjusted based on the min_sensor_count.
 
         - sensor_per_grid: Number of sensors in each newly created sensor grid.
 
+        - out_grid_info: Grid information as written to _info.json.
     """
-    info_file = os.path.join(input_folder, '_info.json')
-
-    assert os.path.isfile(info_file), \
-        'Failed to find the _info.json file. This file should be located inside the ' \
-        'input folder.'
-
-    with open(info_file) as inf:
-        data = json.load(inf)
+    if grid_info is None:
+        info_file = os.path.join(input_folder, '_info.json')
+        assert os.path.isfile(info_file), \
+            'Failed to find the _info.json file. This file should be located inside the ' \
+            'input folder.'
+        with open(info_file) as inf:
+            data = json.load(inf)
+    else:
+        #TODO: add check that validates grid_info
+        data = grid_info
     total_count = sum(grid['count'] for grid in data)
     sensor_per_grid = int(round(total_count / grid_count)) or 1
     if sensor_per_grid < min_sensor_count:
@@ -192,7 +197,8 @@ def redistribute_sensors(
             total_count, grid_count, sensor_per_grid
             )
     )
-    return grid_count, sensor_per_grid
+
+    return grid_count, sensor_per_grid, out_grid_info
 
 
 def restore_original_distribution(
@@ -225,6 +231,10 @@ def restore_original_distribution(
 
     for f in data:
         out_file = os.path.join(output_folder, '%s.%s' % (f['identifier'], extension))
+        # ensure the new folder is created. in case the identifier has a subfolder
+        parent_folder = os.path.dirname(out_file)
+        if not os.path.isdir(parent_folder):
+            os.mkdir(parent_folder)
         with open(out_file, 'w') as outf:
             for src_info in f['dist_info']:
                 src_file = os.path.join(
